==> marble-debuginfo-17.04.3-1.tar.xz: usr/src/debug/marble-17.04.3-1/src/plugins/render/measure/qrc_measuretool.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.6.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/marble/marble-17.04.3-1.i686/src/marble-17.04.3/src/plugins/render/measure/mark.png
  0x0,0x0,0x0,0xb3,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x2,0x3,0x0,0x0,0x0,0x62,0x9d,0x17,0xf2,
  0x0,0x0,0x0,0x3,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0xdb,0xe1,0x4f,0xe0,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xe,0xc4,0x0,0x0,0xe,0xc4,0x1,
  0x95,0x2b,0xe,0x1b,0x0,0x0,0x0,0x9,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0x2d,
  0x33,0x35,0xff,0xff,0xff,0x19,0x9b,0x13,0xff,0x0,0x0,0x0,0x2,0x74,0x52,0x4e,
  0x53,0x0,0x80,0x9b,0x2b,0x4e,0x18,0x0,0x0,0x0,0x33,0x49,0x44,0x41,0x54,0x8,
  0xd7,0x63,0x60,0x0,0x3,0xd1,0x10,0x6,0x6,0xc6,0xd0,0x50,0x7,0x6,0xd6,0xd0,
  0xa9,0x1,0xc,0xa2,0xa1,0x53,0x43,0x20,0x44,0x68,0xe8,0xd4,0x50,0x8,0x11,0xb6,
  0x6a,0xd5,0x52,0x24,0x2e,0x42,0x9,0x58,0x7,0x58,0x2f,0xc8,0x14,0x0,0xc6,0x5e,
  0x13,0x12,0x99,0xf2,0x94,0xbc,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,
  0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // mark.png
  0x0,0x8,
  0x8,0x8e,0x59,0x27,
  0x0,0x6d,
  0x0,0x61,0x0,0x72,0x0,0x6b,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/mark.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)(); }
   } dummy;
}

==> marble-debuginfo-17.08.3-1.tar.xz: usr/src/debug/marble-17.08.3-1/src/plugins/render/measure/qrc_measuretool.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/marble/marble-17.08.3-1.x86_64/src/marble-17.08.3/src/plugins/render/measure/mark.png
  0x0,0x0,0x0,0xb3,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x2,0x3,0x0,0x0,0x0,0x62,0x9d,0x17,0xf2,
  0x0,0x0,0x0,0x3,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0xdb,0xe1,0x4f,0xe0,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xe,0xc4,0x0,0x0,0xe,0xc4,0x1,
  0x95,0x2b,0xe,0x1b,0x0,0x0,0x0,0x9,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0x2d,
  0x33,0x35,0xff,0xff,0xff,0x19,0x9b,0x13,0xff,0x0,0x0,0x0,0x2,0x74,0x52,0x4e,
  0x53,0x0,0x80,0x9b,0x2b,0x4e,0x18,0x0,0x0,0x0,0x33,0x49,0x44,0x41,0x54,0x8,
  0xd7,0x63,0x60,0x0,0x3,0xd1,0x10,0x6,0x6,0xc6,0xd0,0x50,0x7,0x6,0xd6,0xd0,
  0xa9,0x1,0xc,0xa2,0xa1,0x53,0x43,0x20,0x44,0x68,0xe8,0xd4,0x50,0x8,0x11,0xb6,
  0x6a,0xd5,0x52,0x24,0x2e,0x42,0x9,0x58,0x7,0x58,0x2f,0xc8,0x14,0x0,0xc6,0x5e,
  0x13,0x12,0x99,0xf2,0x94,0xbc,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,
  0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // mark.png
  0x0,0x8,
  0x8,0x8e,0x59,0x27,
  0x0,0x6d,
  0x0,0x61,0x0,0x72,0x0,0x6b,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/mark.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x37,0xe9,0x7a,0x68,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_measuretool)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_measuretool)(); }
   } dummy;
}
